==> h2spatial-1.2.0-sources.jar: org/h2gis/h2spatial/internal/type/DomainInfo.java <==
/**
 * h2spatial is a library that brings spatial support to the H2 Java database.
 *
 * h2spatial is distributed under GPL 3 license. It is produced by the "Atelier SIG"
 * team of the IRSTV Institute <http://www.irstv.fr/> CNRS FR 2488.
 *
 * Copyright (C) 2007-2014 IRSTV (FR CNRS 2488)
 *
 * h2patial is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * h2spatial is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * h2spatial. If not, see <http://www.gnu.org/licenses/>.
 *
 * For more information, please consult: <http://www.orbisgis.org/>
 * or contact directly:
 * info_at_ orbisgis.org
 */

package org.h2gis.h2spatial.internal.type;

/**
 * Class helper to define domain. Use defined type
 * @author Nicolas Fortin
 */
public class DomainInfo {
    /** Type alias name */
    private String domainName;
    /** Constraint function associated with this type */
    private int geometryTypeCode;

    /**
     * @param domainName Type alias name
     * @param domainConstraint Constraint function associated with this type
     */
    public DomainInfo(String domainName, int geometryTypeCode) {
        this.domainName = domainName;
        this.geometryTypeCode = geometryTypeCode;
    }

    /**
     * @return Type alias
     */
    public String getDomainName() {
        return domainName;
    }

    /**
     * @return Return one of {@link }
     */
    public int getGeometryTypeCode() {
        return geometryTypeCode;
    }
}

==> h2spatial-1.2.4-sources.jar: org/h2gis/h2spatial/internal/type/DomainInfo.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>.
 *
 * H2GIS is distributed under GPL 3 license. It is produced by CNRS
 * <http://www.cnrs.fr/>.
 *
 * H2GIS is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * H2GIS is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * H2GIS. If not, see <http://www.gnu.org/licenses/>.
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */
package org.h2gis.h2spatial.internal.type;

/**
 * Class helper to define domain. Use defined type
 * @author Nicolas Fortin
 */
public class DomainInfo {
    /** Type alias name */
    private String domainName;
    /** Constraint function associated with this type */
    private int geometryTypeCode;

    /**
     * @param domainName Type alias name
     * @param geometryTypeCode  associated with this type
     */
    public DomainInfo(String domainName, int geometryTypeCode) {
        this.domainName = domainName;
        this.geometryTypeCode = geometryTypeCode;
    }

    /**
     * @return Type alias
     */
    public String getDomainName() {
        return domainName;
    }

    /**
     * @return Return one of {@link }
     */
    public int getGeometryTypeCode() {
        return geometryTypeCode;
    }
}
